Learn R Programming

RKEELjars (version 1.0.20)

getJarList: Get a list with all RKEEL algorithm jars

Description

Method that returns a list with the jar names from RKEEL

Usage

getJarList()

Arguments

Value

Returns a list with the jar names from RKEEL.

Examples

Run this code
# NOT RUN {
getJarList()
# }

Run the code above in your browser using DataLab